% style_risk.m
%
% Produces Figure 7 in:
% Matthias Doepke and Fabrizio Zilibotti, "Parenting with Style: Altruism 
% and Paternalism in Intergenerational Preference Transmission"
% 
% This version: May 8, 2017

close all
clear all

% GENERAL PARAMETERS

options=optimset('Display','off');

% Risk aversion
sig=2;

% Expected consumption
yAV = 1.75;

% Psi_J measures fun of JUV 
Psi_J = 1.5;

% Psi_J measures fun of SMALL (\tilde{\psi}_J in paper)
Psi_S = 1.33;

%p is probability of success 
p = 0.75;
pS = p;
pJ = p;


% START LOOP OVER INEQUALITY
grid=500;

% NOTE: UPPER BOUND MUST BE CHOSEN SO THAT CHILD PREFERS Y OVER S OVER N
scale_grid=linspace(0.7,1.1,grid);

border_VE=[0 0];
border_AN=[0 0];

j=1;
while j<=grid

    % This parameterizes risk
    scale = scale_grid(j);

    % JUVENILE LOTTERY, large variance, large fun 
    SPREADJ = 5*scale;

    % here we calculate yL and yH consistent with the assumed inequality
    % Probability of bad outcome is 0.25
    yL = yAV/(.75*SPREADJ+.25);
    yH = SPREADJ*yL;

    % SMALL LOTTERY, smaller variance, less fun 
    SPREADS = 2*scale;

    % calculate yL and yH in SMALL LOTTERY 
    yLS= yAV/(0.75*SPREADS+.25);
    yHS = SPREADS*yLS;

    % Compute risk aversion that makes child indifferent
    aHAT=fsolve(@(x) pJ*((Psi_J*yH)^(1 - x) - 1)/(1 - x) + (1 - pJ)*((Psi_J*yL)^(1 - x) - 1)/(1 - x)...
        -((yH)^(1 - x) - 1)/(1 - x) ,1.5,options);
    
    % Compute risk aversion that makes child indifferent with regards
    % to small lottery
    aHAT_S=fsolve(@(x) pJ*((Psi_S*yHS)^(1 - x) - 1)/(1 - x) + (1 - pJ)*((Psi_S*yLS)^(1 - x) - 1)/(1 - x)...
        -((yH)^(1 - x) - 1)/(1 - x) ,1.5,options);
    
    % If the difference  is negative, authoritative is always enough to
    % prevent taking both risks
    if aHAT_S<aHAT
        scale_grid(j)
        disp('ERROR: THIS CASE IS NOT COVERED BY THE CODE BELOW');
        pause
    end
    
    % Compute utilities for No Risk, Juvenile and Small lotteries
    % No Risk: Only if utility is aHAT
    UY_N=((yH)^(1 - aHAT) - 1)/(1 -aHAT);
    
    % Juvenile risk: No reason to make risk averse here, a=0
    UY_J=pJ*((Psi_J*yH) - 1) + (1 - pJ)*((Psi_J*yL) - 1);
    
    % Small lottery: Only comes up if utility is aHAT
    UY_S=pJ*((Psi_S*yHS)^(1 - aHAT) - 1)/(1 -aHAT) + (1 - pJ)*((Psi_S*yLS)^(1 - aHAT) - 1)/(1 -aHAT);

    % Now same for the utilities that the parents get
    UO_N=((yH)^(1 - sig) - 1)/(1 -sig);
    UO_J=pJ*((Psi_J*yH)^(1 - sig) - 1)/(1 -sig) + (1 - pJ)*((Psi_J*yL)^(1 - sig) - 1)/(1 -sig);
    UO_S=pJ*((Psi_S*yHS)^(1 - sig) - 1)/(1 -sig) + (1 - pJ)*((Psi_S*yLS)^(1 - sig) - 1)/(1 -sig);
    
    
    % Check that utility conditions are satisfied
    if (UY_J>UY_S) & (UY_S>UY_N) & (UO_N>UO_S) & (UO_S>UO_J)
       
        %disp('THREE STYLES POSSIBLE')

          % Compute lambda that makes parents indifferent between permissive and
          % authoritative
          lam_crit1=(UY_J-UY_S)/(UO_S-UO_J+UY_J-UY_S);
        
          % Compute lambda that makes parents indifferent between authoritarian and
          % authoritative
          lam_crit2=(UY_S-UY_N)/(UO_N-UO_S+UY_S-UY_N);
          
          % Compute lambda that makes parents indifferent between authoritarian and
          % permissive
          lam_crit3=(UY_J-UY_N)/(UO_N-UO_J+UY_J-UY_N);

          % For high enough lambda, there is always an authoritarian zone
          border_AN=[border_AN; yH/yL max(lam_crit2,lam_crit3)];
        
          % There may also be an authoritative region for intermediate
          % lambda
          if lam_crit1< lam_crit2
              border_VE=[border_VE; yH/yL lam_crit1];
          end
              
    elseif (UY_J>UY_S) & (UY_S>UY_N) & (UO_S>UO_N) & (UO_N>UO_J)
    
          %disp('TWO STYLES POSSIBLE')      

          % Compute lambda that makes parents indifferent between permissive and
          % authoritative
          lam_crit=(UY_J-UY_S)/(UO_S-UO_J+UY_J-UY_S);
          border_VE=[border_VE; yH/yL lam_crit];
          
    else

        disp('ERROR: THIS IS NOT SUPPOSED TO HAPPEN') 
        scale_grid(j)
        pause

    end
        
j=j+1;

end

% Remove first elements
border_VE= border_VE(2:size( border_VE,1),:);
border_AN= border_AN(2:size( border_AN,1),:);

hold on
gr=plot(border_VE(:,1), border_VE(:,2),'b',border_AN(:,1), border_AN(:,2),'b');
set(gr,'LineWidth',4);
axis([4 5 .75 1]);
xlabel('Inequality')
ylabel('\lambda')
hold off
